#
# spec file for package ufraw
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ufraw
BuildRequires:  automake
%if 0%{?suse_version} > 1310
BuildRequires:  cfitsio-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  gimp-devel
BuildRequires:  lensfun-devel
BuildRequires:  libexiv2-devel
BuildRequires:  libgtkimageview-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtiff-devel
BuildRequires:  update-desktop-files
Url:            http://ufraw.sourceforge.net/
# gimptool-2.0 --gimpplugindir
%define _gimpplugindir %(gimptool-2.0 --gimpplugindir)
Version:        0.22
Release:        lp150.1.12
Summary:        The Unidentified Flying Raw
License:        GPL-2.0+
Group:          Productivity/Graphics/Other
Source:         http://downloads.sourceforge.net/project/ufraw/ufraw/%{name}-%{version}/%{name}-%{version}.tar.gz
Patch:          %{name}-desktop.patch
Patch1:         %{name}-boundary.patch
Patch2:         %{name}-glibc210.patch
Patch3:         narrowing-conversion.patch
Patch4:         ufraw-gcc7.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Recommends:     %{name}-lang

%description
Application to read and manipulate raw images from digital cameras. It
takes care of the color management, handles the Nikon curve formats and
has an editor for the tone curves. For batch processing of images you
can use the command-line.



Authors:
--------
    Udi Fuchs UdiFuchs@gmail.com

%package -n gimp-ufraw
Summary:        Raw photo loader plugin for The GIMP
Group:          Productivity/Graphics/Other
Obsoletes:      rawphoto < %{version}
Obsoletes:      ufraw-gimp < %{version}
Provides:       gimp-2.0-dcraw-plugin
Provides:       rawphoto = %{version}
Provides:       ufraw-gimp = %{version}
Enhances:       gimp-2.0
Suggests:       dcraw-gnome
%if %{?gimp_api_version:1}0
Requires:       gimp(abi) = %{gimp_abi_version}
Requires:       gimp(api) = %{gimp_api_version}
%else
%requires_eq gimp
%endif

%description -n gimp-ufraw
UFRaw is a utility to read and manipulate raw images from digital
cameras. It can be used as a GIMP plug-in. It reads raw images using
Dave Coffin's raw conversion utility DCRaw. And it supports basic color
management using Little CMS, allowing the user to apply color profiles.



Authors:
--------
    Udi Fuchs UdiFuchs@gmail.com

%lang_package
%prep
%setup -q
%patch
%patch1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
%ifarch ppc64
  export CFLAGS="-m64 $RPM_OPT_FLAGS"
%else
  export CFLAGS="$RPM_OPT_FLAGS"
%endif
export CXXFLAGS="$CFLAGS"
autoreconf -fi
%configure --enable-contrast \
  --enable-dst-correction
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
%suse_update_desktop_file -i ufraw Photography
%find_lang %name

%files lang -f %name.lang

%files
%defattr(-,root,root)
%doc COPYING MANIFEST README TODO
%_bindir/ufraw
%_bindir/ufraw-batch
%_mandir/man?/*
%_datadir/pixmaps/ufraw.png
%_datadir/applications/*.desktop

%files -n gimp-ufraw
%defattr(-,root,root)
%dir %{_libdir}/gimp/
%dir %{_libdir}/gimp/2.0
%_gimpplugindir/plug-ins/

%changelog
* Mon Jun 12 2017 meissner@suse.com
- ufraw-gcc7.patch: pull up the abs() to the call where
  the float -> unsigned int conversions happens.
* Thu Aug 11 2016 schwab@suse.de
- narrowing-conversion.patch: fix narrowing conversion errors
* Mon Feb 29 2016 idonmez@suse.com
- Don't pass --enable-extras to configure, its for code testing
  only and not for distribution (boo#968652)
- Remove conflicts with dcraw.
* Wed Aug 19 2015 idonmez@suse.com
- Add conflicts with dcraw
* Sun Jun 21 2015 gbv@ogimet.com
- Added configuration options
  * --enable-dst-correction
  * --enable-extras
* Sun Jun 21 2015 gbv@ogimet.com
- Updated to version 0.22
- Added FITS support
* Sun Mar  1 2015 meissner@suse.com
- 10/02/2015 - UFRaw-0.21 released, based on DCRaw v 9.23.
  Bug fix release.
- 24/09/2014 - UFRaw-0.20 released, based on DCRaw v 9.22.
  Fuji X-Trans filters are finally supported.
- switch to lcms2
* Tue Feb 24 2015 jengelh@inai.de
- Ignore broken autogen.sh script and call autoreconf directly.
- Remove old specfile macros. Enable parallel build.
- dropped now unused ufraw-automake-1.14.patch
* Thu Oct 16 2014 dimstar@opensuse.org
- Add ufraw-automake-1.14.patch: Add support for automake 1.14.
* Mon Mar 25 2013 salsergey@gmail.com
- Update to version 0.19.2
  * Bug fix release.
* Mon Mar 11 2013 meissner@suse.com
- use Source URL.
* Fri Mar  8 2013 salsergey@gmail.com
- Update to version 0.19.1
  * Maintenance release with lots of bug fixes.
* Tue Jan 22 2013 postadal@suse.cz
- Updated from cvs, based on DCRaw v 9.17
  * Add WB presets for the Panasonic DMC-GH3, DMC-GX1, DMC-LX5,
    SONY DSLR-A330, DSLR-A390, DSLR-A450, SLT-A57, SLT-A65V, NEX-3,
    NEX-5N, NEX-C3, NEX-7, DSC-RX100, Canon EOS 6D, EOS 5D Mark III,
    EOS-1DS, EOS 600D, EOS 1100D, PowerShot G12, PowerShot S95,
    PowerShot S100 NIKON 1 J1, 1 V1, D600, D800, D4, D5100,
    COOLPIX P7100, SAMSUNG EX1, NX100, NX200, OLYMPUS E-5, E-M5,
    XZ-1, E-P3, E-PL2, Leica M9, PENTAX K-r, FUJIFILM FinePix HS20EXR,
    FinePix X100
  * Update WB presets for the Canon EOS 350D, EOS 550D, EOS 7D,
    OLYMPUS E-3, E-PL1
  * Add finetuning for the OLYMPUS E-M5, E-PL1, E-PL, E-PL3
  * Fix trimming of EXIF data
  * Apply auto-crop in ufraw-batch
  * Reset crop data between image loading
  * Keep auto lensfun setting on startup
  * Set the lens geometry according to the lens model
  * Add support for ARRIRAW and Redcode R3D video file formats
  * Various bug fixes when changing LensModel or FocalLength
  * Update the lens crop factor, fixing bug #3161607.
  * Add a "Generic, Crop factor %%f" lens model to get consistent behaviour
  * Read LensFun settings from --conf file
  * Fix spurious warning message about image size too small
* Thu Jan 10 2013 salsergey@gmail.com
- Support for JPEG format added for openSUSE >= 12.2 (it was broken).
* Wed Apr  6 2011 meissner@suse.de
- Updated to 0.18, based on DCRaw v 9.06
  - all changes between DCRaw v 8.99 and 9.06.
  - translation updates
- buildrequire lensfun
* Fri Dec 31 2010 aj@suse.de
- Fix packagelist.
* Wed Sep  1 2010 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Sat May  1 2010 postadal@suse.cz
- updated to 0.17, based on DCRaw v 8.99
  * Lens distortion corrections using lensfun is enabled by default
  * Added a despeckling/denoising algorithm to solve issues with images
    taken under very difficult lighting conditions
  * Added support for hot pixel elimination
  * Calculate live histogram from working color-space instead of display
    color-space
  * Calculate live histogram from cropped area only
  * Added auto-crop option
  * Allow upto 400%% zoom
  * Added lightness adjustmens by hue
  * Added --color-smoothing, --maximize-window command line options
  * Configurable frame lines overlay
  * OpenMP support for preview redrawing and VNG interpolation
  * Added rotation control to the transformations page of the GUI
* Mon Aug 31 2009 coolo@novell.com
- do not use 2.00 as boolean
* Thu Aug 20 2009 crrodriguez@suse.de
- use gimp plugin versioning
* Thu Aug  6 2009 postadal@suse.cz
- renamed ufraw-gimp -> gimp-ufraw (bnc#349082)
* Wed Jun  3 2009 coolo@novell.com
- cast the result of strrchr to fix build with glibc 2.10
* Mon Feb 23 2009 coolo@suse.de
- fix the lang subpackage split
* Thu Feb 19 2009 coolo@suse.de
- update to 0.15, based on DCRaw v 8.89.
  * Multiprocessing support using OpenMP. Patch by Bruce Guenter.
  * Add progress report during the loading of raw files.
  * Add JPEG optimization to reduce the file size without effecting image quality.
  * Compatibility with the just released Exiv2-0.18.
  * Support sRAW1 and sRAW2 formats of the Canon 50D and 5D Mark II.
  * Some annoying bugs got squashed.
  * Change license from 'GPLv2' to 'GPLv2 or later'.
  * more see http://ufraw.sourceforge.net/
- require lang subpackage
- enabled in KDE menu again (bnc#298969)
- enabled contrast setting
* Fri Dec  7 2007 nadvornik@suse.cz
- updated to 0.13
  * Simplified output path logic - output path defaults to the path of the input path.
  * Added 'System profile' option to read display ICC profile from the X display. Based on code from Gimp.
  * Do not read/write display ICC profile from/to ID files.
  * Show camera white balance in EXIF page. Patch by Erik Burrows.
  * Automatically fit histograms to allocated height.
  * Read Canon lens from EXIF data. Patch by Andreas Steinel.
  * Improved PPG interpolation. Patch by Alain Desbiolles.
  * Remember maximized state of window between sessions.
  * Add color smoothing option to all interpolation. Based on patch by alexander melkozerov. AHD+smoothing is exactly the same as the now obsolete EAHD.
  * Added darkframe to GUI (patch by Bruce Guenter).
  * Darkframe subtraction also handles hot pixels (patch by Bruce Guenter).
  * Show spot values only if spot is selected and allow unselecting spot values.
  * Add FITS output. Patch by Andreas Steinel. This option is disabled by default.
  * Progressive JPEG encoding. Patch by Bruce Guenter.
  * Blink over/under exposure in preview. Patch by Bruce Guenter.
  * Enable --output option for stand-alone tool. It forces the output filename to the value specified. It is useful for F-Spot. Patch by Stephane Delcroix.
  * Reimplemented the EXIF page. Patch by Andrew Zabolotny.
  * Display flash mode in EXIF page.
  * Moved shrink/size controls from Save dialog to main window.
  * Added delete button to stand-alone tool.
  * Added 'send to Gimp' option to stand-alone tool.
  * Made the save-as button an icon only, to save space.
  * Added option to save as PNG 8 or 16 bits.
  * Write EXIF data to PNG files. Based on code from DigiKam.
  * Added aspect ratio control. Patch by Andrew Zabolotny.
  * New Spanish translation by Enrique Jorreto Ledesma.
  * New Polish translation by Tomasz Golinski.
  * New Korean translation by Homin Lee.
- built with GtkImageView, added modifications made by hfiguiere@novell.com
* Tue Aug 21 2007 postadal@suse.cz
- disabled in KDE menu [#298969]
* Mon Aug 13 2007 postadal@suse.cz
- enabled exiv2 support [#298890]
- fixed crash when spot selector reached image boundary (crash_fix.patch)
- fixed handling of non integer shrink factors
- some TIFF images were wrongly identified as raw file
* Mon Aug  6 2007 postadal@suse.cz
- updated to version 0.12
  * full color management workflow with camera, display and output profiles
  * image cropping, rotate/flip support
  * added scrolling and panning (based on the new GtkImageView widget)
  * added support for dcraw's wavelet denoising
  * added Patterned Pixel Grouping (PPG) Interpolation. It can be even better
    than other interpolations in some cases and much faster
  * added EAHD interpolation. It is an enhancement of the AHD interpolation
    with another phase of color smoothing. The improvement is mostly seen
    in high contrast as it removes color artifacts such as chromatic aberration
  * read raw files compressed with gzip or bzip2
  * display luminosity value and Adams' zone for spot value
  * added 'max zoom' (only 50%% at the moment) and 'zoom to fit' buttons
  * retain some hue and saturation when clipping pixels (in positive exposure
    compensation, and mostly for Canon cameras where positive exposure
    is applied by default)
  * added a Cinepaint plug-in (disabled by default)
  * based the user interface more on icons and less on text
- fixed build (gcc.patch)
- reverted entry for this application in the menu (this is real application)
* Wed Aug  1 2007 stbinner@suse.de
- fix capitalization of GenericName entry in .desktop file
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Mon May 28 2007 schwab@suse.de
- Fix writing beyond array bounds.
* Fri Mar  9 2007 postadal@suse.cz
- updated to version 0.11
  * option to restore highlights, relevant when applying negative
    exposure correction (in HSV sharp details or in LCH soft natural details)
  * option for soft, filmlike clipping of highlights, relevant when applying
    positive exposure correction
  * correct Canon DSLRs exposure by default (raw images are under exposed)
  * translations to Danish, Japanese and Portuguese
- removed obsoleted autogen.patch
- call gimptool-2.0 --gimpplugindir to set right path
* Wed Feb  7 2007 postadal@suse.cz
- updated to version 0.10
  * obsoleted patches po.patch and wb_presets.patch
- fixed gcc warning (gcc.patch) [#240197]
* Tue Jan 16 2007 aj@suse.de
- Changes for GNOME in /usr.
* Mon Nov 27 2006 stbinner@suse.de
- NoDisplay=true instead of Hidden=true in .desktop file
* Tue Nov 21 2006 stbinner@suse.de
- don't show entry for this application in the menu
* Sat Oct 28 2006 meissner@suse.de
- also use RPM_OPT_FLAGS for CXXFLAGS.
* Fri Oct 27 2006 postadal@suse.cz
- center the raw histogram if the rest of the controls are too wide
- duplicate the Leica R8 WB presets for the Lecia R9 (wb_presets.patch)
- updated Russian and French translation (po.patch)
* Mon Oct 23 2006 postadal@suse.cz
- updated from cvs
  * fixes
- provides and obsoletes rawphoto package (gimp-plugin)
* Sat Oct 21 2006 schwab@suse.de
- Fix bogus version check.
* Mon Oct 16 2006 postadal@suse.cz
- updated from cvs
  * updated dcraw to 8.40 (1.352)
  * a lot of new WB presets
  * --embedded-image for reading the embedded preview image in raw files
  * Russian and Danish translations
* Thu Sep 14 2006 sbrabec@suse.cz
- Moved GIMP related provides and requires to ufraw-gimp.
* Tue Aug 15 2006 postadal@suse.cz
- updated to version 0.9.1
  * updated dcraw to 8.29 (1.340)
  * recognize Sony's *.arw file type
  * treat Minolta's Alpha and Maxxum as the Dynax for WB presets
* Fri Aug  4 2006 postadal@suse.cz
- updated to version 0.9
  * add darkframe subtraction option
  * more conservative highlight unclipping
  * support filenames in URI format
* Wed Aug  2 2006 postadal@suse.cz
- updated from cvs
  * fixed zoom support (WB ...)
  * show EXIF data
  * updated dcraw to 8.28 (1.338)
  * replaced old dcraw interface with C++ interface
  * fixes
* Tue May 16 2006 postadal@suse.cz
- updated to version 0.8.1
  * fixed Gimp plug-in half-interpolation crash
  * fixed possible crash in auto-exposure
* Wed Mar 29 2006 postadal@suse.cz
- handled 'spot_wb' in --conf correctly [ufraw#1456944] (config2.patch)
- updated dcraw to 8.10 (1.320) (wb.patch)
  * better support the Imacon Ixpress 22-Mp
  * added WB support for Olympus C5060WZ and C8080WZ
* Sun Mar 26 2006 postadal@suse.cz
- fixed converting old config [ufraw#1456944] (config.patch)
* Sun Mar 26 2006 postadal@suse.cz
- updated from cvs
  * updated dcraw to 8.09 (1.319)
  * much more accurate white balance temperature setting
  * white balance presets per camera model
  * show the channel multipliers in the UI
  * apply base curve before gamma curve
  * fix camera specific bugs for Sony F828, Sigma Foveon, Nikon D2H, D1X
- added libstdc++-devel, gcc-c++ to BuildRequires
* Thu Jan 26 2006 postadal@suse.cz
- updated from cvs
  * updated dcraw to 8.03 (1.313)
- added -fstack-protector
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 sbrabec@suse.cz
- Enhances gimp in both branches, Suggests dcraw-gnome.
* Fri Jan  6 2006 postadal@suse.cz
- updated from cvs
- removed obsoleted patch gcc.patch
* Fri Nov 18 2005 postadal@suse.cz
- updated to version 0.6
  * fixed bug in AHD interpolation in the border of image
- fixed gcc warning (gcc.patch)
- added -m64 for ppc64 building
* Mon Oct 17 2005 sbrabec@suse.cz
- Provide gimp-2.0-dcraw-plugin virtual.
* Thu Oct 13 2005 postadal@suse.cz
- updated from cvs
  * uses new dcraw with AHD support
* Thu Sep 29 2005 postadal@suse.cz
- initial version 0.5
